@@ -13,10 +13,12 @@ from jaseci.api.architype_api import architype_api
 from jaseci.api.config_api import config_api
 from jaseci.api.interface import interface
 from jaseci.api.master_api import master_api
+from jaseci.api.jac_api import jac_api
 
 
-class master(element, interface, master_api, alias_api, graph_api, object_api,
-             sentinel_api, walker_api, architype_api):
+class master(element, interface, master_api, alias_api,
+             graph_api, object_api, sentinel_api, walker_api,
+             architype_api, jac_api):
     """Main class for master functions for user"""
 
     def __init__(self, head_master=None, *args, **kwargs):
@@ -29,6 +31,7 @@ class master(element, interface, master_api, alias_api, graph_api, object_api,
         graph_api.__init__(self)
         walker_api.__init__(self)
         sentinel_api.__init__(self)
+        interface.__init__(self)
 
     def destroy(self):
         """
