@@ -13,22 +13,25 @@ import requests
 from jaseci.utils.mem_hook import mem_hook
 from jaseci.utils.utils import copy_func
 from jaseci.element.super_master import super_master
-from jaseci.api.public_api import public_api
 from .book_tools import book
 
-session = {
-    "filename": "js.session",
-    "user": [super_master(h=mem_hook(), name='admin')],
-    "mem-only": False
-}
-session['master'] = session['user'][0]
-
-connection = {'url': None, 'token': None, 'headers': None}
+session = None
+connection = None
 
 
-def blank_func():
-    """No help provided"""
-    pass
+def reset_state():
+    global session, connection
+    session = {
+        "filename": "js.session",
+        "user": [super_master(h=mem_hook(), name='admin')],
+        "mem-only": session["mem-only"] if session is not None else False
+    }
+    session['master'] = session['user'][0]
+
+    connection = {'url': None, 'token': None, 'headers': None}
+
+
+reset_state()
 
 
 @shell(prompt='jaseci > ', intro='Starting Jaseci Shell...')
@@ -36,7 +39,7 @@ def blank_func():
               help="Specify filename for session state.")
 @click.option('--mem-only', '-m', is_flag=True,
               help="Set true to not save file for session.")
-def cli(filename, mem_only):
+def jsctl(filename, mem_only):
     """
     The Jaseci Command Line Interface
     """
@@ -48,13 +51,19 @@ def cli(filename, mem_only):
 
 
 def remote_api_call(payload, api_name):
-    """Constructs and issues call to remote server"""
-    if(api_name.startswith('api_')):
-        path = '/jac/'+api_name[4:]
-    elif(api_name.startswith('admin_api_')):
-        path = '/admin/'+api_name[10:]
-    elif(api_name.startswith('public_api_')):
-        path = '/public/'+api_name[11:]
+    """
+    Constructs and issues call to remote server
+    NOTE: Untested
+    """
+    for i in super_master.all_apis(None):
+        if(api_name == '_'.join(i['groups'])):
+            if(i in super_master._private_api):
+                path = '/jac/'+api_name
+            elif(i in super_master._admin_api):
+                path = '/admin/'+api_name
+            elif(i in super_master._public_api):
+                path = '/public/'+api_name
+            break
     ret = requests.post(connection['url']+path,
                         json=payload,
                         headers=connection['headers'])
@@ -79,6 +88,9 @@ def interface_api(api_name, is_public, **kwargs):
     if('code' in kwargs and kwargs['code']):
         if (os.path.isfile(kwargs['code'])):
             with open(kwargs['code'], 'r') as file:
+                if(api_name == 'sentinel_register' and
+                   'name'in kwargs and kwargs['name'] == 'default'):
+                    kwargs['name'] = kwargs['code']
                 kwargs['code'] = file.read()
         else:
             click.echo(f"Code file {kwargs['code']} not found!")
@@ -91,8 +103,7 @@ def interface_api(api_name, is_public, **kwargs):
     if(connection['token'] and connection['url']):
         out = remote_api_call(kwargs, api_name)
     elif(is_public):
-        out = public_api(session['master']._h).general_interface_to_api(
-            kwargs, api_name)
+        out = session['master'].public_interface_to_api(kwargs, api_name)
     else:
         out = session['master'].general_interface_to_api(kwargs, api_name)
     if(isinstance(out, dict) or isinstance(out, list)):
@@ -113,31 +124,17 @@ def extract_api_tree():
     signatures in leaves from API function names in Master
     """
     api_funcs = {}
-    for i in dir(session['master'])+dir(public_api(None)):
-        if (i.startswith('api_') or i.startswith('admin_api_') or
-                i.startswith('public_api_')):
-            is_public = False
-            # Get function names and signatures
-            if i.startswith('api_'):
-                func_str = i[4:]
-            elif i.startswith('admin_'):
-                func_str = i[10:]
-            else:  # is public api
-                func_str = i[11:]
-                is_public = True
-            cmd_groups = func_str.split('_')
-            func_sig = session['master'].get_api_signature(
-                i) if not is_public else public_api(None).get_api_signature(i)
-            func_doc = session['master'].get_api_doc(
-                i) if not is_public else public_api(None).get_api_doc(i)
-
-            # Build hierarchy of command groups
-            api_root = api_funcs
-            for j in cmd_groups:
-                if (j not in api_root.keys()):
-                    api_root[j] = {}
-                api_root = api_root[j]
-            api_root['leaf'] = [i, func_sig, is_public, func_doc]
+    for i in session['master'].all_apis() + \
+            session['master']._cli_api:
+        # Build hierarchy of command groups
+        api_root = api_funcs
+        for j in i['groups']:
+            if (j not in api_root.keys()):
+                api_root[j] = {}
+            api_root = api_root[j]
+        api_root['leaf'] = ['_'.join(i['groups']), i['sig'],
+                            i in session['master']._public_api,  i['doc'],
+                            i['cli_args']]
     return api_funcs
 
 
@@ -155,6 +152,7 @@ def build_cmd(group_func, func_name, leaf):
     f.__doc__ = leaf[3]
 
     func_sig = leaf[1]
+    cli_args = leaf[4]
     for i in func_sig.parameters.keys():
         if(i == 'self'):
             continue
@@ -162,7 +160,9 @@ def build_cmd(group_func, func_name, leaf):
         p_type = func_sig.parameters[i].annotation
         if(p_type not in [int, bool, float]):
             p_type = str
-        if(p_default is not func_sig.parameters[i].empty):
+        if(i in cli_args):
+            f = click.argument(f'{i}', type=p_type)(f)
+        elif(p_default is not func_sig.parameters[i].empty):
             f = click.option(
                 f'-{i}', default=p_type(p_default), required=False,
                 type=p_type)(f)
@@ -176,7 +176,7 @@ def build_cmd(group_func, func_name, leaf):
     return group_func.command()(f)
 
 
-def cmd_tree_builder(location, group_func=cli, cmd_str=''):
+def cmd_tree_builder(location, group_func=jsctl, cmd_str=''):
     """
     Generates Click command groups from API tree recursively
     """
@@ -186,7 +186,7 @@ def cmd_tree_builder(location, group_func=cli, cmd_str=''):
             build_cmd(group_func, i, loc['leaf'])
             continue
         else:
-            f = copy_func(blank_func, i)
+            f = copy_func(lambda: None, i)
             f.__doc__ = f'Group of `{(cmd_str+" "+i).lstrip()}` commands'
             new_func = group_func.group()(f)
         cmd_tree_builder(loc, new_func, cmd_str+' '+i)
@@ -235,6 +235,12 @@ def clear():
     click.clear()
 
 
+@click.command(help="Reset jsctl (clears state)")
+def reset():
+    reset_state()
+    click.echo(f"Jaseci State Cleared!")
+
+
 @click.command(help="Internal book generation tools")
 @click.argument("op", type=str, default='cheatsheet', required=True)
 @click.option('--output', '-o', default='', required=False, type=str,
@@ -252,16 +258,17 @@ def tool(op, output):
         click.echo(f'[saved to {output}]')
 
 
-cli.add_command(login)
-cli.add_command(edit)
-cli.add_command(ls)
-cli.add_command(clear)
-cli.add_command(tool)
+jsctl.add_command(login)
+jsctl.add_command(edit)
+jsctl.add_command(ls)
+jsctl.add_command(clear)
+jsctl.add_command(reset)
+jsctl.add_command(tool)
 cmd_tree_builder(extract_api_tree())
 
 
 def main():
-    cli()
+    jsctl()
 
 
 if __name__ == '__main__':
